package
Version:
v1.3.1
Opens a new window with list of versions in this module.
Published: Feb 7, 2026
License: MIT
Opens a new window with license information.
Imports: 0
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
Package entity defines core data structures used throughout the application.
Commit represents a parsed git log entry.
type Task struct {
Type string `json:"type"`
Message string `json:"message"`
Icon string `json:"icon"`
Enabled bool `json:"enabled"`
}
Task represents a manual or recurring task.
Source Files
¶
Click to show internal directories.
Click to hide internal directories.