Documentation
¶
Overview ¶
Package editor handles opening external text editors for interactive content editing.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Client ¶
type Client struct {
// contains filtered or unexported fields
}
Client handles opening external editors.
func NewClient ¶
func NewClient() *Client
NewClient creates a new editor client with auto-detected editor.
func NewClientWithEditor ¶
NewClientWithEditor creates a new editor client with a specific editor command.
Click to show internal directories.
Click to hide internal directories.